( cd usr/bin ; rm -rf neqn )
( cd usr/bin ; ln -sf gneqn neqn )
( cd usr/bin ; rm -rf nroff )
( cd usr/bin ; ln -sf gnroff nroff )
( cd usr/bin ; rm -rf indxbib )
( cd usr/bin ; ln -sf gindxbib indxbib )
( cd usr/bin ; rm -rf lookbib )
( cd usr/bin ; ln -sf glookbib lookbib )
( cd usr/bin ; rm -rf pic )
( cd usr/bin ; ln -sf gpic pic )
( cd usr/bin ; rm -rf refer )
( cd usr/bin ; ln -sf grefer refer )
( cd usr/bin ; rm -rf troff )
( cd usr/bin ; ln -sf groff troff )
( cd usr/bin ; rm -rf tbl )
( cd usr/bin ; ln -sf gtbl tbl )
( cd usr/bin ; rm -rf soelim )
( cd usr/bin ; ln -sf gsoelim soelim )
( cd usr/bin ; rm -rf eqn )
( cd usr/bin ; ln -sf geqn eqn )
( cd usr/bin ; rm -rf addftinfo )
( cd usr/bin ; ln -sf /cdrom/usr/bin/addftinfo addftinfo )
( cd usr/bin ; rm -rf afmtodit )
( cd usr/bin ; ln -sf /cdrom/usr/bin/afmtodit afmtodit )
( cd usr/bin ; rm -rf geqn )
( cd usr/bin ; ln -sf /cdrom/usr/bin/geqn geqn )
( cd usr/bin ; rm -rf gindxbib )
( cd usr/bin ; ln -sf /cdrom/usr/bin/gindxbib gindxbib )
( cd usr/bin ; rm -rf glookbib )
( cd usr/bin ; ln -sf /cdrom/usr/bin/glookbib glookbib )
( cd usr/bin ; rm -rf gneqn )
( cd usr/bin ; ln -sf /cdrom/usr/bin/gneqn gneqn )
( cd usr/bin ; rm -rf gnroff )
( cd usr/bin ; ln -sf /cdrom/usr/bin/gnroff gnroff )
( cd usr/bin ; rm -rf gpic )
( cd usr/bin ; ln -sf /cdrom/usr/bin/gpic gpic )
( cd usr/bin ; rm -rf grefer )
( cd usr/bin ; ln -sf /cdrom/usr/bin/grefer grefer )
( cd usr/bin ; rm -rf grodvi )
( cd usr/bin ; ln -sf /cdrom/usr/bin/grodvi grodvi )
( cd usr/bin ; rm -rf groff )
( cd usr/bin ; ln -sf /cdrom/usr/bin/groff groff )
( cd usr/bin ; rm -rf grog )
( cd usr/bin ; ln -sf /cdrom/usr/bin/grog grog )
( cd usr/bin ; rm -rf grotty )
( cd usr/bin ; ln -sf /cdrom/usr/bin/grotty grotty )
( cd usr/bin ; rm -rf gsoelim )
( cd usr/bin ; ln -sf /cdrom/usr/bin/gsoelim gsoelim )
( cd usr/bin ; rm -rf gtbl )
( cd usr/bin ; ln -sf /cdrom/usr/bin/gtbl gtbl )
( cd usr/bin ; rm -rf gtroff )
( cd usr/bin ; ln -sf /cdrom/usr/bin/gtroff gtroff )
( cd usr/bin ; rm -rf lkbib )
( cd usr/bin ; ln -sf /cdrom/usr/bin/lkbib lkbib )
( cd usr/bin ; rm -rf pfbtops )
( cd usr/bin ; ln -sf /cdrom/usr/bin/pfbtops pfbtops )
( cd usr/bin ; rm -rf psbb )
( cd usr/bin ; ln -sf /cdrom/usr/bin/psbb psbb )
( cd usr/bin ; rm -rf tfmtodit )
( cd usr/bin ; ln -sf /cdrom/usr/bin/tfmtodit tfmtodit )
( cd usr/bin ; rm -rf grops )
( cd usr/bin ; ln -sf /cdrom/usr/bin/grops grops )
( cd usr/lib ; rm -rf groff )
( cd usr/lib ; ln -sf /cdrom/usr/lib/groff groff )
( cd usr ; rm -rf man )
( cd usr ; ln -sf /cdrom/usr/man man )
